@@ -14,17 +14,18 @@ try:
 except ImportError: #python 3 zip is same as izip
     izip = zip
 
-from .globaling import *
-from .odicting import odict
+from ..aid.sixing import *
+from .globaling import AUX, MOOT, INDENT_ADD, ScheduleNames
+from ..aid.odicting import odict
 
-from . import aiding
-from .aiding import nonStringIterable, nameToPath
+from ..aid.classing import metaclassify, nonStringIterable
+from ..aid.aiding import nameToPath
 from . import excepting
 from . import registering
 from . import storing
 from . import framing
 
-from .consoling import getConsole
+from ..aid.consoling import getConsole
 console = getConsole()
 
 
@@ -123,6 +124,8 @@ class Act(object):
                 # each key is share src path, and value is list of src fields
                 for src, fields in self.prerefs.get('inits', {}).items():
                     src = self.resolvePath(ipath=src, warn=True) # now a share
+                    if not fields:  # default is use existing fields
+                        fields = self._prepareSrcFields(src, fields)
                     for field in fields:  # requires src pre inited
                         if field in src:  # only update if src has field
                             inits[field] = src[field]
@@ -137,6 +140,8 @@ class Act(object):
                 # each key is share src path, and value is list of src fields
                 for src, fields in self.prerefs.get('parms', {}).items():
                     src = self.resolvePath(ipath=src, warn=True) # now a share
+                    if not fields:  # default is use existing fields
+                        fields = self._prepareSrcFields(src, fields)
                     for field in fields:  # requires src pre inited
                         if field in src:  # only update if src has field
                             parms[field] = src[field]
@@ -146,6 +151,8 @@ class Act(object):
                 # each key is share src path, and value is list of src fields
                 for src, fields in self.prerefs.get('ioinits', {}).items():
                     src = self.resolvePath(ipath=src, warn=True) # now a share
+                    if not fields:  # default is use existing fields
+                        fields = self._prepareSrcFields(src, fields)
                     for field in fields:  # requires src pre inited
                         if field in src:  # only update if src has field
                             ioinits[field] = src[field]
@@ -179,70 +186,107 @@ class Act(object):
             self.actor._prepare(**self.parms)
 
     def resolvePath(self, ipath, ival=None, iown=None, warn=False):
-        """ Returns resolved Share or Node instance from ipath
-            ipath may be path name of share or node
-            or reference to Share or Node instance
+        """
+        Returns resolved Share or Node instance from ipath
+        ipath may be path name of share or node
+        or reference to Share or Node instance
 
-            This method resolves pathname strings into share and node references
-            at resolve time.
+        This method resolves pathname strings into share and node references
+        at resolve time.
 
-            ival is optional value for share
-            iown is optional ownership if True then overwrite if exists
-                   otherwise do not overwrite
+        ival is optional value for share
+        iown is optional ownership if True then overwrite if exists
+               otherwise do not overwrite
 
-            if warn then will complain if the share is created.
+        if warn then will complain if the share is created.
 
-            It allows for substitution into ipath of
-            frame, framer, actor, main frame, or main framer relative names.
-            So that lexically relative pathnames can
-            be dynamically resolved in support of framer cloning.
-            It assumes that any implied variants have been reconciled.
-            If .actor is not yet instantiated then raises exception if ipath
-               uses actor relative addressing. This may occur for init prerefs.
+        It allows for substitution into ipath of
+        frame, framer, actor, main frame, or main framer relative names.
+        So that lexically relative pathnames can
+        be dynamically resolved in support of framer cloning.
+        It assumes that any implied variants have been reconciled.
+        If .actor is not yet instantiated then raises exception if ipath
+           uses actor relative addressing. This may occur for init prerefs.
 
-            When ipath is a string:  (not a Node or Share reference)
-                the following syntax is used:
+        When ipath is a string:  (not a Node or Share reference)
+            the following syntax is used:
 
-                If the path name starts with a leading '.' dot then path name is
-                fully reconciled and no contextual substitutions are to be applied.
+            If the path name starts with a leading '.' dot then path name is
+            fully reconciled and no contextual substitutions are to be applied.
 
-                Otherwise make subsitutions in pathname strings that begin
-                with 'framer.'
-                Substitute for special path part 'framer' with names of 'me' or 'main'
-                Substitute for special path part 'frame' with names  of 'me' or 'main'
-                Substitute for special path part 'actor' with name of 'me'
+            Otherwise make subsitutions in pathname strings that begin
+            with 'framer.'
+            Substitute for special path part 'framer' with names of 'me' or 'main'
+            Substitute for special path part 'frame' with names  of 'me' or 'main'
+            Substitute for special path part 'actor' with name of 'me'
 
-                'me' indicates substitute the current framer, frame, or actor name
-                respectively.
+            'me' indicates substitute the current framer, frame, or actor name
+            respectively.
 
-                'main' indicates substitute the current frame's main framer or main frame
-                name respectively obtained from
+            'main' indicates substitute the current frame's main framer or main frame
+            name respectively obtained from
 
-            When  ipath is a pathname string that resolves to a Share and ival is not None
-            Then ival is used to initialize the share values.
-                ival should be a share initializer:
-                   valid initializers are:
-                       a dict of fields and values
-                       a list of duples, each a (key, value) item
+        If ipath ends with a '.' then it resolves to a node
+        Otherwise if not trailing dot it resolves to a share
 
-                If own is True then .update(ival) is used
-                Otherwise .create(ival) is used
+        When  ipath is a pathname string that resolves to a Share and ival is not None
+        Then ival is used to initialize the share values.
+            ival should be a share initializer:
+               valid initializers are:
+                   a dict of fields and values
+                   a list of duples, each a (key, value) item
 
-            Requires that:
-               self.store exist
+            If own is True then .update(ival) is used
+            Otherwise .create(ival) is used
 
-               The following have already been resolved:
-                   self.frame
-                   self.frame.framer
-                   self.frame.framer.main
-                   self.frame.framer.main.framer
+        Requires that:
+           self.store exist
 
-               If actor relative addressing is used then:
-                  self.actor is resolved
-                  self.actor.name is not empty
+           The following have already been resolved:
+               self.frame
+               self.frame.framer
+               self.frame.framer.main
+               self.frame.framer.main.framer
+
+           If actor relative addressing is used then:
+              self.actor is resolved
+              self.actor.name is not empty
 
         """
         if not (isinstance(ipath, storing.Share) or isinstance(ipath, storing.Node)): # must be pathname
+            if not ipath.startswith('.'): # not reconciled so do relative substitutions
+                parts = ipath.split('.')
+                if parts[0] == 'me':  #  framer inode relative addressing
+                    if not self.frame:
+                        raise excepting.ResolveError("ResolveError: Missing frame context"
+                                " to resolve relative pathname.", ipath, self,
+                                self.human, self.count)
+                    if not self.frame.framer:
+                        raise excepting.ResolveError("ResolveError: Missing framer context"
+                                " to resolve relative pathname.", ipath, self.frame,
+                                self.human, self.count)
+                    del parts[0]
+
+                    finode = ''  # inode of framer
+                    framer = self.frame.framer
+                    finode = framer.inode
+                    if framer.main:  # aux framer so special meaning of main or mine
+                        if finode == "main":  # replace finode with main framer inode
+                            finode = framer.main.framer.inode
+                        elif finode == "mine":  # don't prepend main framer inode
+                            finode = ""
+                        else:  # possibly prepend main framer inode if finode relative
+                            minode = framer.main.framer.inode
+                            minode = minode.rstrip('.')
+                            if not finode.startswith('.') and minode:  # prepend if relative
+                                finode = '.'.join([minode, finode])
+                    finode = finode.rstrip('.')
+                    if finode:
+                        finparts = finode.split('.')
+                        if finparts:
+                            parts = finparts + parts
+                    ipath = '.'.join(parts)
+
             if not ipath.startswith('.'): # not reconciled so do relative substitutions
                 parts = ipath.split('.')
                 if parts[0] == 'framer':  #  relative addressing
@@ -259,7 +303,7 @@ class Act(object):
                         parts[1] = self.frame.framer.name
                     elif parts[1] == 'main': # current main framer
                         if not self.frame.framer.main:
-                            raise excepting.ResolveError("ResolveError: Missing main frame"
+                            raise excepting.ResolveError("ResolveError: Missing main framer"
                                 " context to resolve relative pathname.", ipath,
                                 self.frame.framer,
                                 self.human, self.count)
@@ -294,6 +338,7 @@ class Act(object):
                                                self.human, self.count)
                                 parts[3:4] = nameToPath(self.actor.name).lstrip('.').rstrip('.').split('.')
 
+
                 ipath = '.'.join(parts)
 
             if not self.frame.store:
@@ -319,6 +364,25 @@ class Act(object):
 
         return ipath
 
+    def _prepareSrcFields(self, src, fields):
+        """
+        Prepares and verifys list field names fields in share src
+           handles default conditions when fields is empty
+
+           src is share
+           fields is list of field names
+
+        """
+        if not fields: # empty source fields so assign defaults
+            if src:
+                if 'value' in src:
+                    fields = ['value'] #use value field
+                else: #use pre-existing source fields
+                    fields = src.keys()
+            else: # empty src
+                fields = ['value'] #use value field
+        return fields
+
 class Nact(Act):
     """ Negating Act used for actor needs to give Not Need
     """
@@ -389,12 +453,12 @@ class SideAct(Act):
                                          self.human,
                                          self.count)
 
-def actorify(name, base=None, registry=None, inits=None, ioinits=None, parms=None,
+def actify(name, base=None, registry=None, inits=None, ioinits=None, parms=None,
              parametric=None):
     """ Parametrized decorator function that converts the decorated function
         into an Actor sub class with .action method and with class name that
-        is name and registers the new subclass in the registry under name.
-        If base is not provided then use Actor
+        is name and registers the new subclass in the registry under name as
+        a subclass of base. The default base is Actor.
 
         The parameters  registry, parametric, inits, ioinits, and parms if provided,
         are used to create the class attributes for the new subclass
@@ -409,7 +473,7 @@ def actorify(name, base=None, registry=None, inits=None, ioinits=None, parms=Non
     if registry:
         attrs['Registry'] = odict()
     if parametric is not None:
-        attrs['_Parametric'] = parametric
+        attrs['_Parametric'] = True if parametric else False
     if inits:
         attrs['Inits'] = odict(inits)
     if ioinits:
@@ -426,7 +490,9 @@ def actorify(name, base=None, registry=None, inits=None, ioinits=None, parms=Non
         return inner
     return implicit
 
-@aiding.metaclassify(registering.RegisterType) # python2or3 compatible
+actorify = actify  # alias for backwards compatibility
+
+@metaclassify(registering.RegisterType) # python2or3 compatible
 class Actor(object):
     """ Actor Base Class
         Has Actor specific Registry of classes
@@ -439,15 +505,18 @@ class Actor(object):
     __slots__ = ('name', 'store', '_act')
 
     def __init__(self, name='', store=None, act=None, **kwa ):
-        """ Initialization method for instance.
-
-            Instance attributes
-                .name = name string for Actor variant in class Registry
-                .store = reference to shared data Store
-                ._act = reference to containing Act
         """
-        super(Actor,self).__init__(**kwa) # in case of MRO
+        Initialization method for instance.
 
+        Instance attributes
+            .name = name string for Actor variant in class Registry
+            .store = reference to shared data Store
+            ._act = reference to containing Act
+
+        If subclass has init need to call super
+        super(SubClassName, self).__init__(**kwa)
+
+        """
         self.name = name
         if store is not None:
             if  not isinstance(store, storing.Store):
@@ -455,13 +524,17 @@ class Actor(object):
             self.store = store
         self._act = act
 
+
     def __call__(self, **kwa):
         """ run .action  """
         return self.action(**kwa)
 
     def action(self, **kwa):
         """Action called by Actor. Should override in subclass."""
-        console.profuse("Actioning {0} with {1}\n".format(self.name, str(kwa)))
+        console.profuse("Actioning {0} in {1} of {2} with {3}\n".format(self.name,
+                                                                        self._act.frame.name,
+                                                                        self._act.frame.framer.name,
+                                                                        str(kwa)))
         pass
 
     def _expose(self):
@@ -478,84 +551,110 @@ class Actor(object):
         return parms
 
     def _initio(self, inode='', **kwa):
-        """ Intialize and hookup ioflo shares from node pathname inode and kwa arguments.
-            This implements a generic Actor interface protocol for associating the
-            io data flow shares to the Actor.
+        """
+        Compute initializations for ioflo shares from inode and kwa arguments.
+        This implements a generic Actor interface protocol for associating the
+        io data flow shares to the Actor.
 
-            inode is the computed pathname string of the default share node
-            where shares associated with the Actor instance may be placed when
-            relative addressing is used.
+        inode is the computed pathname string of the default share node
+        where shares associated with the Actor instance may be placed when
+        relative addressing is used.
 
-            The values of the items in the **kwa argument may be either strings or
-            mappings
+        The inode is computed as absolute, relative, or default.
+        When not provided the default inode is  'framer.me.frame.me.actor.me.'
+        When the inode is relative it is relative to the framer inode
+        If the framer is a cloned auxiliary then the inode could be relative
+          to the main framer inode
 
-            For each key,val in **kwa.items() there are the following 2 forms for val:
+        The values of the items in the **kwa argument may be either strings or
+        mappings
 
-            1- string:
-               ipath = pathnamestring
-            2- dict of items (mapping) of form:
-                {
-                    ipath: "pathnamestring", (optional)
-                    ival: initial value, (optional)
-                    iown: truthy, (optional)
-                }
+        For each key,val in **kwa.items() there are the following 2 forms for val:
 
-            In either case, three init values are produced, these are:
-                ipath, ival, iown,
-            Missing init values from ipath, ival, iown will be assigned a
-            default value as per the rules below:
+        1- string:
+           ipath = pathnamestring
+        2- dict of items (mapping) of form:
+            {
+                ipath: "pathnamestring", (optional)
+                ival: initial value, (optional)
+                iown: truthy, (optional)
+            }
 
-            For each kwa item (key, val)
-                key is the name of the associated instance attribute or action parm.
-                Extract ipath, ival, iown from val
+        In either case, three init values are produced, these are:
+            ipath, ival, iown,
+        Missing init values from ipath, ival, iown will be assigned a
+        default value as per the rules below:
 
-                Shares are initialized with mappings passed into share.create or
-                share.update. So to assign ival to share.value pass into share.create
-                or share.update a mapping of the form {'value': ival} whereas
-                passing in an empty mapping does nothing.
+        For each kwa item (key, val)
+            key is the name of the associated instance attribute or action parm.
+            Extract ipath, ival, iown from val
 
-                If ipath not provided
-                    ipath is the default path inode.key
-                Else ipath is provided
-                    If ipath starts with dot "." Then absolute path
-                    Else ipath does not start with dot "." Then relative path from inode
+            Shares are initialized with mappings passed into share.create or
+            share.update. So to assign ival to share.value pass into share.create
+            or share.update a mapping of the form {'value': ival} whereas
+            passing in an empty mapping does nothing.
 
-                    If ipath ends with dot Then the path is to a node not share
-                            node ref is created and remaining init values are ignored
+            If ipath not provided
+                ipath is the default path inode.key
+            Else ipath is provided
+                If ipath starts with dot "." Then absolute path
+                Else ipath does not start with dot "." Then relative path from inode
+
+                If ipath ends with dot Then the path is to a node not share
+                        node ref is created and remaining init values are ignored
 
 
-                If ival not provided
-                     set ival to empty mapping which when passed to share.create
-                     will not change share.value
-                Else ival provided
-                    If ival is an empty Mapping Then
-                        assign a shallow copy of ival to share.value by passing
-                        in {value: ival (copy)} to share.create/.update
-                    Else If ival is a non-string iterable and not a mapping
-                        assign a shallow copy of ival to share.value by passing
-                        in {value: ival (copy)} to share.create/.update
-                    Else If ival is a non-empty Mapping Then
-                        Each item in ival is assigned as a field, value pair in the share
-                        by passing ival directly into share.create or share.update
-                        This means there is no way to init a share.value to a non empty mapping
-                        It is possible to init a share.value to an empty mapping see below
-                    Else
-                        assign ival to share.value by by passing
-                        in {value: ival} to share.create or share.update
-
-                Create share with pathname given by ipath
-
-                If iown Then
-                    init share with ival value using update
+            If ival not provided
+                 set ival to empty mapping which when passed to share.create
+                 will not change share.value
+            Else ival provided
+                If ival is an empty Mapping Then
+                    assign a shallow copy of ival to share.value by passing
+                    in {value: ival (copy)} to share.create/.update
+                Else If ival is a non-string iterable and not a mapping
+                    assign a shallow copy of ival to share.value by passing
+                    in {value: ival (copy)} to share.create/.update
+                Else If ival is a non-empty Mapping Then
+                    Each item in ival is assigned as a field, value pair in the share
+                    by passing ival directly into share.create or share.update
+                    This means there is no way to init a share.value to a non empty mapping
+                    It is possible to init a share.value to an empty mapping see below
                 Else
-                    init share with ival value using create ((change if not exist))
+                    assign ival to share.value by by passing
+                    in {value: ival} to share.create or share.update
+
+            Create share with pathname given by ipath
+
+            If iown Then
+                init share with ival value using update
+            Else
+                init share with ival value using create ((change if not exist))
 
         """
         if not isinstance(inode, basestring):
             raise ValueError("Nonstring inode arg '{0}'".format(inode))
 
-        if not inode:
-            #inode = aiding.nameToPath(self.name)
+        finode = ''  # inode of framer
+        if self._act.frame.framer:
+            framer = self._act.frame.framer
+            finode = framer.inode
+            if framer.main:  # aux framer so special meaning of main or mine
+                if finode == "main":  # replace finode with main framer inode
+                    finode = framer.main.framer.inode
+                elif finode == "mine":  # don't prepend main framer inode
+                    finode = ""  # effectively empty inode
+                else:  # possibly prepend main framer inode if finode relative
+                    minode = framer.main.framer.inode
+                    minode = minode.rstrip('.')
+                    if not finode.startswith('.') and minode:  # prepend if relative
+                        finode = '.'.join([minode, finode])
+
+        finode = finode.rstrip('.')
+
+        if not inode.startswith('.') and finode:  # not absolute and finode so prepend
+            inode = ".".join([finode, inode])
+
+        if not inode:  # empty or missing use default actor relative
             inode = "framer.me.frame.me.actor.me."
 
         if not inode.endswith('.'):
@@ -594,7 +693,11 @@ class Actor(object):
                 if not ipath.startswith('.'): # full path is inode joined to ipath
                     ipath = '.'.join((inode.rstrip('.'), ipath)) # when inode empty prepends dot
             else:
-                ipath = '.'.join(inode.rstrip('.'), key)
+                ipath = '.'.join((inode.rstrip('.'), key))  # when ipath empty create default from key
+
+            if ipath.startswith('me.') or ipath == 'me':
+                raise ValueError("Invalid ipath '{0}', first part == 'me'".format(ipath))
+
             ioi = odict(ipath=ipath, ival=ival, iown=iown)
             iois[key] = ioi
 
@@ -611,10 +714,7 @@ class Actor(object):
             If one is using this method consider refactoring into two different
             behaviors
         """
-        # eventually replace postinitio with _prepare
-        # for temporary backwards compatibility call postinitio
-        if hasattr(self, 'postinitio'):
-            self.postinitio(**kwa)
+        pass
 
     def _resolvePath(self, ipath, ival=None, iown=None, warn=False):
         """ Returns resolved Share or Node instance from ipath
@@ -675,7 +775,7 @@ class Actor(object):
             if field not in dst:
                 console.profuse("     Warning: Transfer into non-existent field '{0}' in "
                        "share {1} ... creating anyway\n".format(field, dst.name))
-                dst[field] = 0 #create
+                dst[field] = None #create
 
         return dstFields
 
@@ -731,13 +831,13 @@ class Actor(object):
             if field not in src:
                 console.profuse("     Warning: Transfer from non-existent field '{0}' "
                         "in share {1} ... creating anyway".format(field, src.name))
-                src[field] = 0.0 #create
+                src[field] = None #create
 
         for field in dstFields: #use destination fields for destination data
             if field not in dst:
                 console.profuse("     Warning: Transfer into non-existent field '{0}' "
                         "in share {1} ... creating anyway\n".format(field, dst.name))
-                dst[field] = 0.0 #create
+                dst[field] = None #create
 
         return (srcFields, dstFields)
 
